@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactiondeleteheader.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
@@ -22,13 +9,14 @@
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
-#include <QWidget>
-#include <QLabel>
-#include <QXmlStreamReader>
 #include "libksieve_debug.h"
 #include <QGridLayout>
+#include <QLabel>
+#include <QWidget>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
 
@@ -39,20 +27,21 @@ SieveActionDeleteHeader::SieveActionDeleteHeader(SieveEditorGraphicalModeWidget
 
 QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    QGridLayout *grid = new QGridLayout;
-    grid->setContentsMargins(0, 0, 0, 0);
+    auto w = new QWidget(parent);
+    auto grid = new QGridLayout;
+    grid->setContentsMargins({});
     w->setLayout(grid);
 
-    SelectMatchTypeComboBox *matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto matchType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchType->setObjectName(QStringLiteral("matchtype"));
     connect(matchType, &SelectMatchTypeComboBox::valueChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(matchType, 0, 0);
 
-    QLabel *lab = new QLabel(i18n("header:"));
+    auto lab = new QLabel(i18n("header:"));
     grid->addWidget(lab, 0, 1);
 
-    QLineEdit *headerEdit = new QLineEdit;
+    auto headerEdit = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(headerEdit, w);
     headerEdit->setObjectName(QStringLiteral("headeredit"));
     connect(headerEdit, &QLineEdit::textChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(headerEdit, 0, 2);
@@ -60,7 +49,8 @@ QWidget *SieveActionDeleteHeader::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("value:"));
     grid->addWidget(lab, 1, 1);
 
-    QLineEdit *valueEdit = new QLineEdit;
+    auto valueEdit = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(valueEdit, w);
     valueEdit->setObjectName(QStringLiteral("valueedit"));
     connect(valueEdit, &QLineEdit::textChanged, this, &SieveActionDeleteHeader::valueChanged);
     grid->addWidget(valueEdit, 1, 2);
@@ -82,14 +72,14 @@ void SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w,
             element.skipCurrentElement();
             return;
         } else if (tagName == QLatin1String("tag")) {
-            SelectMatchTypeComboBox *combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto combo = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             combo->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), isNegative), name(), error);
         } else if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                QLineEdit *edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
+                auto edit = w->findChild<QLineEdit *>(QStringLiteral("headeredit"));
                 edit->setText(element.readElementText());
             } else if (index == 1) {
-                QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
+                auto value = w->findChild<QLineEdit *>(QStringLiteral("valueedit"));
                 value->setText(element.readElementText());
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -98,10 +88,10 @@ void SieveActionDeleteHeader::parseValue(QXmlStreamReader &element, QWidget *w,
             ++index;
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << "SieveActionAddHeader::setParamWidgetValue unknown tag " << tagName;
