@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SIEVEACTIONRETURN_H
-#define SIEVEACTIONRETURN_H
+#pragma once
 
 #include "sieveaction.h"
 namespace KSieveUi
@@ -23,4 +22,3 @@ public:
 };
 }
 
-#endif // SIEVEACTIONRETURN_H
