@@ -1,24 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionvacation.h"
-#include "editor/sieveeditorutil.h"
-#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
+#include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
+#include "editor/sieveeditorutil.h"
 #include "widgets/multilineedit.h"
 #include "widgets/selectvacationcombobox.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include "libksieve_debug.h"
+#include <KSieveUi/AbstractSelectEmailLineEdit>
+#include <QGridLayout>
 #include <QLabel>
 #include <QSpinBox>
-#include "libksieve_debug.h"
 #include <QXmlStreamReader>
-#include <QGridLayout>
-#include <KSieveUi/AbstractSelectEmailLineEdit>
 
 using namespace KSieveUi;
 
@@ -30,14 +31,14 @@ SieveActionVacation::SieveActionVacation(SieveEditorGraphicalModeWidget *sieveGr
 
 QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *grid = new QGridLayout;
+    auto w = new QWidget(parent);
+    auto grid = new QGridLayout;
     grid->setContentsMargins({});
     w->setLayout(grid);
 
     QLabel *lab = nullptr;
     if (mHasVacationSecondsSupport) {
-        auto *vacation = new SelectVacationComboBox;
+        auto vacation = new SelectVacationComboBox;
         vacation->setObjectName(QStringLiteral("vacationcombobox"));
         connect(vacation, &SelectVacationComboBox::valueChanged, this, &SieveActionVacation::valueChanged);
         grid->addWidget(vacation, 0, 0);
@@ -46,7 +47,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
         grid->addWidget(lab, 0, 0);
     }
 
-    auto *day = new QSpinBox;
+    auto day = new QSpinBox;
     day->setMinimum(1);
     day->setMaximum(999);
     day->setObjectName(QStringLiteral("day"));
@@ -56,7 +57,8 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Message subject:"));
     grid->addWidget(lab, 1, 0);
 
-    auto *subject = new QLineEdit;
+    auto subject = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(subject, w);
     subject->setObjectName(QStringLiteral("subject"));
     connect(subject, &QLineEdit::textChanged, this, &SieveActionVacation::valueChanged);
     grid->addWidget(subject, 1, 1);
@@ -73,7 +75,7 @@ QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Vacation reason:"));
     grid->addWidget(lab, 3, 0);
 
-    auto *text = new MultiLineEdit;
+    auto text = new MultiLineEdit;
     connect(text, &MultiLineEdit::valueChanged, this, &SieveActionVacation::valueChanged);
     text->setObjectName(QStringLiteral("text"));
     grid->addWidget(text, 3, 1);
@@ -89,15 +91,15 @@ void SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget
             const QString tagValue = element.readElementText();
             if (tagValue == QLatin1String("seconds")) {
                 if (mHasVacationSecondsSupport) {
-                    auto *vacationcombobox = w->findChild<SelectVacationComboBox *>(QStringLiteral("vacationcombobox"));
+                    auto vacationcombobox = w->findChild<SelectVacationComboBox *>(QStringLiteral("vacationcombobox"));
                     vacationcombobox->setCode(AutoCreateScriptUtil::tagValue(tagValue), name(), error);
                 } else {
                     serverDoesNotSupportFeatures(QStringLiteral("seconds"), error);
                 }
             } else if (tagValue == QLatin1String("days")) {
-                //Nothing wait num tag for it.
+                // Nothing wait num tag for it.
             } else if (tagValue == QLatin1String("addresses")) {
-                auto *addresses = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("addresses"));
+                auto addresses = w->findChild<AbstractSelectEmailLineEdit *>(QStringLiteral("addresses"));
                 if (element.readNextStartElement()) {
                     const QStringRef textElementTagName = element.name();
                     if (textElementTagName == QLatin1String("str")) {
@@ -107,24 +109,24 @@ void SieveActionVacation::setParamWidgetValue(QXmlStreamReader &element, QWidget
                     }
                 }
             } else if (tagValue == QLatin1String("subject")) {
-                auto *subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
+                auto subject = w->findChild<QLineEdit *>(QStringLiteral("subject"));
                 subject->setText(AutoCreateScriptUtil::strValue(element));
             } else {
                 unknownTagValue(tagValue, error);
                 qCDebug(LIBKSIEVE_LOG) << "SieveActionVacation::setParamWidgetValue unknown tagValue :" << tagValue;
             }
         } else if (tagName == QLatin1String("num")) {
-            auto *day = w->findChild<QSpinBox *>(QStringLiteral("day"));
+            auto day = w->findChild<QSpinBox *>(QStringLiteral("day"));
             day->setValue(element.readElementText().toInt());
         } else if (tagName == QLatin1String("str")) {
-            auto *text = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
+            auto text = w->findChild<MultiLineEdit *>(QStringLiteral("text"));
             text->setPlainText(element.readElementText());
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else {
             unknownTag(tagName, error);
             qCDebug(LIBKSIEVE_LOG) << " SieveActionVacation::setParamWidgetValue unknown tagName " << tagName;
@@ -163,7 +165,7 @@ QString SieveActionVacation::code(QWidget *w) const
     if (!textStr.isEmpty()) {
         result += QStringLiteral(" text:%1").arg(AutoCreateScriptUtil::createMultiLine(textStr));
     } else {
-        result += QLatin1Char(';');    //Be sure to have ";"
+        result += QLatin1Char(';'); // Be sure to have ";"
     }
     return result;
 }
@@ -191,10 +193,12 @@ QStringList SieveActionVacation::needRequires(QWidget *) const
 QString SieveActionVacation::help() const
 {
     QString helpStr = i18n(
-        "The \"vacation\" action implements a vacation autoresponder similar to the vacation command available under many versions of Unix. Its purpose is to provide correspondents with notification that the user is away for an extended period of time and that they should not expect quick responses.");
+        "The \"vacation\" action implements a vacation autoresponder similar to the vacation command available under many versions of Unix. Its purpose is to "
+        "provide correspondents with notification that the user is away for an extended period of time and that they should not expect quick responses.");
     if (mHasVacationSecondsSupport) {
-        helpStr = QLatin1Char('\n') + i18n(
-            "Through the \":days\" parameter, it limits the number of auto-replies to the same sender to one per [n] days, for a specified number of days. But there are cases when one needs more granularity, if one would like to generate \"vacation\" replies more frequently.");
+        helpStr = QLatin1Char('\n')
+            + i18n("Through the \":days\" parameter, it limits the number of auto-replies to the same sender to one per [n] days, for a specified number of "
+                   "days. But there are cases when one needs more granularity, if one would like to generate \"vacation\" replies more frequently.");
         helpStr += QLatin1Char('\n') + i18n("This extension defines a \":seconds\" parameter to provide more granularity for such situations.");
     }
     return helpStr;
