@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionaddress.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include "widgets/selectaddresspartcombobox.h"
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
-#include "widgets/selectheadertypecombobox.h"
 #include "editor/sieveeditorutil.h"
+#include "widgets/selectaddresspartcombobox.h"
+#include "widgets/selectheadertypecombobox.h"
 
 #include <KLocalizedString>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
-#include "libksieve_debug.h"
 #include <QXmlStreamReader>
 
 using namespace KSieveUi;
@@ -26,30 +26,30 @@ SieveConditionAddress::SieveConditionAddress(SieveEditorGraphicalModeWidget *sie
 
 QWidget *SieveConditionAddress::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *selectAddressPart = new SelectAddressPartComboBox(mSieveGraphicalModeWidget);
+    auto selectAddressPart = new SelectAddressPartComboBox(mSieveGraphicalModeWidget);
     connect(selectAddressPart, &SelectAddressPartComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectAddressPart->setObjectName(QStringLiteral("addresspartcombobox"));
     lay->addWidget(selectAddressPart);
 
-    auto *grid = new QGridLayout;
+    auto grid = new QGridLayout;
     grid->setContentsMargins({});
     lay->addLayout(grid);
-    auto *selectMatchCombobox = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto selectMatchCombobox = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     connect(selectMatchCombobox, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectMatchCombobox->setObjectName(QStringLiteral("matchtypecombobox"));
     grid->addWidget(selectMatchCombobox, 0, 0);
 
-    auto *selectHeaderType = new SelectHeaderTypeComboBox(true);
+    auto selectHeaderType = new SelectHeaderTypeComboBox(true);
     connect(selectHeaderType, &SelectHeaderTypeComboBox::valueChanged, this, &SieveConditionAddress::valueChanged);
     selectHeaderType->setObjectName(QStringLiteral("headertypecombobox"));
     grid->addWidget(selectHeaderType, 0, 1);
 
-    QLabel *lab = new QLabel(i18n("address:"));
+    auto lab = new QLabel(i18n("address:"));
     grid->addWidget(lab, 1, 0);
 
     AbstractRegexpEditorLineEdit *edit = AutoCreateScriptUtil::createRegexpEditorLineEdit();
@@ -76,8 +76,9 @@ QString SieveConditionAddress::code(QWidget *w) const
 
     const AbstractRegexpEditorLineEdit *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
     const QString addressStr = AutoCreateScriptUtil::createAddressList(edit->code().trimmed(), false);
-    return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("address %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr)
-           + AutoCreateScriptUtil::generateConditionComment(comment());
+    return AutoCreateScriptUtil::negativeString(isNegative)
+        + QStringLiteral("address %1 %2 %3 %4").arg(selectAddressPartStr, matchTypeStr, selectHeaderTypeStr, addressStr)
+        + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 QStringList SieveConditionAddress::needRequires(QWidget *w) const
@@ -91,7 +92,8 @@ QStringList SieveConditionAddress::needRequires(QWidget *w) const
 QString SieveConditionAddress::help() const
 {
     return i18n(
-        "The \"address\" test matches Internet addresses in structured headers that contain addresses.  It returns true if any header contains any key in the specified part of the address, as modified by the comparator and the match keyword.");
+        "The \"address\" test matches Internet addresses in structured headers that contain addresses.  It returns true if any header contains any key in the "
+        "specified part of the address, as modified by the comparator and the match keyword.");
 }
 
 void SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
@@ -107,10 +109,10 @@ void SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidg
             ++index;
         } else if (tagName == QLatin1String("str")) {
             if (indexStr == 0) {
-                auto *selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
                 selectHeaderType->setCode(element.readElementText());
             } else if (indexStr == 1) {
-                auto *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
                 edit->setCode(AutoCreateScriptUtil::quoteStr(element.readElementText()));
             } else {
                 tooManyArguments(tagName, indexStr, 2, error);
@@ -119,10 +121,10 @@ void SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidg
             ++indexStr;
         } else if (tagName == QLatin1String("list")) {
             if (indexStr == 0) {
-                auto *selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
+                auto selectHeaderType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertypecombobox"));
                 selectHeaderType->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else if (indexStr == 1) {
-                auto *edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
+                auto edit = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("editaddress"));
                 edit->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else {
                 tooManyArguments(tagName, indexStr, 2, error);
@@ -131,7 +133,7 @@ void SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidg
             ++indexStr;
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
@@ -144,21 +146,21 @@ void SieveConditionAddress::setParamWidgetValue(QXmlStreamReader &element, QWidg
     }
     if (lstTagValue.count() == 1) {
         QString specificError;
-        auto *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+        auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
         selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(lstTagValue.at(0), notCondition), name(), specificError);
-        if (!specificError.isEmpty()) { //Test if default match type == is
-            auto *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
+        if (!specificError.isEmpty()) { // Test if default match type == is
+            auto selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
             selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(lstTagValue.at(0)), name(), error);
         }
     } else if (lstTagValue.count() == 2) {
         QString errorStr;
-        auto *selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
+        auto selectAddressPart = w->findChild<SelectAddressPartComboBox *>(QStringLiteral("addresspartcombobox"));
         selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(lstTagValue.at(0)), name(), errorStr);
         if (errorStr.isEmpty()) {
-            auto *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+            auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
             selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(lstTagValue.at(1), notCondition), name(), error);
-        } else { //Problem with order
-            auto *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+        } else { // Problem with order
+            auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
             selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(lstTagValue.at(0), notCondition), name(), error);
             selectAddressPart->setCode(AutoCreateScriptUtil::tagValue(lstTagValue.at(1)), name(), error);
         }
