@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTHEADERTYPECOMBOBOX_H
-#define SELECTHEADERTYPECOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 #include <QDialog>
@@ -47,9 +46,9 @@ private:
     void slotAddNewHeader();
     void readConfig();
     void writeConfig();
-    SelectHeadersWidget *mListWidget = nullptr;
-    QLineEdit *mNewHeader = nullptr;
-    QPushButton *mAddNewHeader = nullptr;
+    SelectHeadersWidget *const mListWidget;
+    QLineEdit *const mNewHeader;
+    QPushButton *const mAddNewHeader;
 };
 
 class SelectHeaderTypeComboBox : public QComboBox
@@ -77,4 +76,3 @@ private:
 };
 }
 
-#endif // SELECTHEADERTYPECOMBOBOX_H
