@@ -107,7 +107,7 @@ int SieveTextEdit::lineNumberAreaWidth() const
         ++digits;
     }
 
-    const int space = 2 + fontMetrics().boundingRect(QLatin1Char('9')).width() * digits;
+    const int space = 2 + fontMetrics().boundingRect(QLatin1Char('X')).width() * digits;
     return space;
 }
 
