@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,8 +13,8 @@ using namespace KSieveUi;
 
 IncludeFileLineEdit::IncludeFileLineEdit(QWidget *parent)
     : LineEditValidator(parent)
+    , mCompleter(new QCompleter(this))
 {
-    mCompleter = new QCompleter(this);
     mCompleter->setObjectName(QStringLiteral("completer"));
     mCompleter->setCaseSensitivity(Qt::CaseInsensitive);
     mStringListModel = new QStringListModel(this);
